@@ -376,6 +376,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
     double celesteThreshold;
     config->Read(wxT("/Celeste/Threshold"), &celesteThreshold, HUGIN_CELESTE_THRESHOLD);
     bool celesteSmall=config->Read(wxT("/Celeste/Filter"), HUGIN_CELESTE_FILTER)==0;
+    bool runLinefind=config->Read(wxT("/Assistant/Linefind"), HUGIN_ASS_LINEFIND)!=0;
     bool runCPClean=config->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN)!=0;
     double scale;
     config->Read(wxT("/Assistant/panoDownsizeFactor"), &scale, HUGIN_ASS_PANO_DOWNSIZE_FACTOR);
@@ -398,7 +399,7 @@ void AssistantPanel::OnAlign( wxCommandEvent & e )
     std::ofstream makefile(makefileName.mb_str(HUGIN_CONV_FILENAME));
     makefile.exceptions( std::ofstream::eofbit | std::ofstream::failbit | std::ofstream::badbit );
     std::string scriptString(scriptName.mb_str(HUGIN_CONV_FILENAME));
-    HuginBase::AssistantMakefilelibExport::createMakefile(*m_pano,progs,runCeleste,celesteThreshold,celesteSmall,
+    HuginBase::AssistantMakefilelibExport::createMakefile(*m_pano,progs,runLinefind,runCeleste,celesteThreshold,celesteSmall,
         runCPClean,scale,makefile,scriptString);
     makefile.close();
 
