@@ -76,6 +76,8 @@ class PanosphereSphereTool;
 class PanosphereOverviewOutlinesTool;
 class PlaneOverviewOutlinesTool;
 
+class PreviewGuideTool;
+
 class GLPreviewFrame;
 
 class GLwxAuiManager;
@@ -84,6 +86,7 @@ class GLwxAuiFloatingFrame;
 #include <wx/string.h>
 #include <wx/frame.h>
 #include <wx/aui/aui.h>
+#include <wx/clrpicker.h>
 
 #include <iostream>
 
@@ -243,6 +246,9 @@ public:
      */
     void UpdateGlobalWhiteBalance(double redFactor, double blueFactor);
     void UpdateIdentifyTools(std::set<unsigned int> new_image_set);
+
+    wxColour GetPreviewBackgroundColor();
+    
 protected:
 
     bool GLresize;
@@ -311,11 +317,21 @@ protected:
     void OnLayoutScaleChange(wxScrollEvent &e);
     /** event handler when starting color picker */
     void OnColorPicker(wxCommandEvent &e);
+    /** event handler when user changes background color */
+    void OnPreviewBackgroundColorChanged(wxColourPickerEvent & e);
+    /** event handler when user selects different guide */
+    void OnGuideChanged(wxCommandEvent &e);
+    
 private:
     /** changes the visibility of the group check boxes
      * @param isShown true if the group checkboxes should be visible
      */
     void EnableGroupCheckboxes(bool isShown);
+    /** updates the mode of the overview window
+     *  @param newMode overview mode which should be setted
+     *  @return true, of mode was successful changed to desired mode
+     */
+    bool UpdateOverviewMode(int newMode);
     /** The dock manager */
     GLwxAuiManager * m_mgr;
 
@@ -344,6 +360,9 @@ private:
     wxChoice * m_DragModeChoice;
     wxChoice * m_ProjectionChoice;
     wxChoice * m_OverviewModeChoice;
+    wxChoice * m_GuideChoiceCrop;
+    wxChoice * m_GuideChoiceDrag;
+    wxChoice * m_GuideChoiceProj;
     // No HDR display yet.
     // wxChoice * m_outputModeChoice;
     wxTextCtrl * m_exposureTextCtrl;
@@ -358,6 +377,8 @@ private:
     bool m_projectionStatusPushed;
 #endif
 
+    wxColour m_preview_background_color;
+
     wxString m_choices[3];
     int m_oldProjFormat;
     // index of difference mode
@@ -384,7 +405,7 @@ private:
     std::vector<ImageGroupButtonEventHandler *> toggle_group_button_event_handlers;
 
     wxToggleButton * m_OverviewToggle;
-    
+
     DECLARE_EVENT_TABLE()
 
     // tools
@@ -430,12 +451,20 @@ private:
     PanosphereOverviewOutlinesTool *overview_outlines_tool;
     PlaneOverviewOutlinesTool *plane_overview_outlines_tool;
 
+    PreviewGuideTool *preview_guide_tool;
+
     void TurnOffTools(std::set<Tool*> tools);
 
 #ifdef __WXGTK__
     bool loadedLayout;
 #endif
 
+    /** check, if panorama has non-zero translation parameters
+     *  @returns true, if panorama has non-zero translation parameters
+     */
+    bool HasNonZeroTranslationParameters();
+    /** resets all translation parameters to zero */
+    void ResetTranslationParameters();
     void CleanButtonColours();
     /** Tell the user anything suspicious about the projection choice.
      * If nothing is suspicious, any previous message is removed.
