@@ -274,6 +274,30 @@ void ImagesList::SelectSingleImage(unsigned int imgNr)
     SetItemState(imgNr, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
 }
 
+void ImagesList::SelectImageRange(unsigned int imgStart,unsigned int imgEnd)
+{
+    size_t nrItems = GetItemCount();
+    size_t _imgStart=imgStart;
+    size_t _imgEnd=imgEnd;
+    if(imgEnd<imgStart)
+    {
+        _imgStart=imgEnd;
+        _imgEnd=imgStart;
+    }
+    for (size_t i=0; i < nrItems ; i++)
+    {
+        int selected = GetItemState(i, wxLIST_STATE_SELECTED);
+        if ((i < _imgStart || i>_imgEnd ) && selected)
+        {
+            SetItemState(i, 0, wxLIST_STATE_SELECTED);
+        }
+    }
+    for(size_t i=_imgStart; i<=_imgEnd; i++)
+    {
+        SetItemState(i, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
+    };
+};
+
 void ImagesList::SelectAll()
 {
     unsigned int nrItems = GetItemCount();
@@ -283,6 +307,17 @@ void ImagesList::SelectAll()
     }
 }
 
+void ImagesList::DeselectAll()
+{
+    unsigned int nrItems = GetItemCount();
+    for (unsigned int i=0; i < nrItems ; i++) {
+        int selected = GetItemState(i, wxLIST_STATE_SELECTED);
+        if (selected) {
+            SetItemState(i, 0, wxLIST_STATE_SELECTED);
+        }
+    }
+}
+
 void ImagesList::OnItemSelected ( wxListEvent & e )
 {
     DEBUG_TRACE(e.GetIndex());
@@ -314,7 +349,7 @@ void ImagesList::OnChar(wxKeyEvent &e)
             };
         case 1: //Ctrl+A
             {
-                if(!m_singleSelect && e.ControlDown())
+                if(!m_singleSelect && e.CmdDown())
                 {
                     SelectAll();
                 }
