@@ -308,7 +308,10 @@ void ImagesPanel::ChangePano ( std::string type, double var )
 void ImagesPanel::SIFTMatching(wxCommandEvent & e)
 {
     UIntSet selImg = images_list->GetSelected();
-    if ( selImg.size() < 2) {
+    //if only one image is selected, run detector on all images, except for linefind
+    wxString progName=cpdetector_config.settings[m_CPDetectorChoice->GetSelection()].GetProg().Lower();
+    if ((selImg.size()==0) || (selImg.size()==1 && progName.Find(wxT("linefind"))==wxNOT_FOUND))
+    {
         // add all images.
         selImg.clear();
         unsigned int nImg = pano->getNrOfImages();
@@ -495,8 +498,6 @@ void ImagesPanel::ListSelectionChanged(wxListEvent & e)
             ShowImgParameters(imgNr);
             m_optAnchorButton->Enable();
             m_colorAnchorButton->Enable();
-            m_moveDownButton->Enable();
-            m_moveUpButton->Enable();
         } else {
             DEBUG_DEBUG("Multiselection, or no image selected");
             // multiselection, clear all values
@@ -504,9 +505,10 @@ void ImagesPanel::ListSelectionChanged(wxListEvent & e)
             ClearImgParameters();
             m_optAnchorButton->Disable();
             m_colorAnchorButton->Disable();
-            m_moveDownButton->Disable();
-            m_moveUpButton->Disable();
         }
+        bool movePossible=*(sel.begin())+sel.size()-1 == *(sel.rbegin());
+        m_moveDownButton->Enable(movePossible);
+        m_moveUpButton->Enable(movePossible);
     }
 }
 
@@ -603,12 +605,22 @@ void ImagesPanel::ShowExifInfo(unsigned int imgNr)
         SetLabel(wxFileName(wxString(val.c_str(),HUGIN_CONV_FILENAME)).GetFullName());
 
     val = img.getExifMake();
-    XRCCTRL(*this, "images_camera_make",wxStaticText) ->
-        SetLabel(wxString(val.c_str(),wxConvLocal));
+    if(val!="Unknown")
+    {
+        XRCCTRL(*this, "images_camera_make",wxStaticText)->SetLabel(wxString(val.c_str(),wxConvLocal));
+    };
 
     val = img.getExifModel();
-    XRCCTRL(*this, "images_camera_model",wxStaticText) ->
-        SetLabel(wxString(val.c_str(),wxConvLocal));
+    if(val!="Unknown")
+    {
+        XRCCTRL(*this, "images_camera_model",wxStaticText)->SetLabel(wxString(val.c_str(),wxConvLocal));
+    };
+
+    val = img.getExifLens();
+    if(val!="Unknown")
+    {
+        XRCCTRL(*this, "images_lens",wxStaticText)->SetLabel(wxString(val.c_str(),wxConvLocal));
+    };
 
     struct tm exifdatetime;
     if(img.getExifDateTime(&exifdatetime)==0)
@@ -685,10 +697,12 @@ void ImagesPanel::ClearImgExifInfo()
     XRCCTRL(*this, "images_filename", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_camera_make", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_camera_model", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_lens", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_capture_date", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_focal_length", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_aperture", wxStaticText) ->SetLabel(wxT(""));
     XRCCTRL(*this, "images_shutter_speed", wxStaticText) ->SetLabel(wxT(""));
+    XRCCTRL(*this, "images_iso", wxStaticText) ->SetLabel(wxT(""));
 }
 
 
@@ -854,6 +868,11 @@ void ImagesPanel::OnRemoveImages(wxCommandEvent & e)
     for (UIntSet::iterator it = selImg.begin(); it != selImg.end(); ++it) {
         filenames.push_back(pano->getImage(*it).getFilename());
     }
+    //deselect images if multiple image were selected
+    if(selImg.size()>1)
+    {
+        images_list->DeselectAll();
+    };
     DEBUG_TRACE("Sending remove images command");
     GlobalCmdHist::getInstance().addCommand(
         new PT::RemoveImagesCmd(*pano, selImg)
@@ -904,42 +923,64 @@ void ImagesPanel::OnRemoveCtrlPoints(wxCommandEvent & e)
 void ImagesPanel::OnMoveImageDown(wxCommandEvent & e)
 {
     UIntSet selImg = images_list->GetSelected();
-    if ( selImg.size() == 1) {
-        unsigned int i1 = *selImg.begin();
+    size_t num = selImg.size();
+    if(num>0)
+    {
+        //last selected image
+        unsigned int i1 = *selImg.rbegin();
+        //image to move into
         unsigned int i2 = i1+1;
-        if (i2 < pano->getNrOfImages() ) {
-            images_list->SetItemState(i1,0,wxLIST_STATE_SELECTED);
+        //Test if there is room to move images down
+        if (i2 < pano->getNrOfImages() )
+        {
+            //Group repeated move commands within undo history
+            std::vector<PanoCommand*> cmds;
+            for (size_t i=0; i<num; i++)
+            {
+                cmds.push_back(new SwapImagesCmd(*pano,i2, i1));
+                i1--;
+                i2--;
+             }
             GlobalCmdHist::getInstance().addCommand(
-                new SwapImagesCmd(*pano,i1, i2)
-            );
+                new PT::CombinedPanoCommand(*pano, cmds));
             // set new selection
-            images_list->SelectSingleImage(i2);
+            images_list->SelectImageRange(*selImg.begin()+1,*selImg.begin()+num);
             // Bring the focus back to the button.
-            m_moveDownButton->CaptureMouse();
-            m_moveDownButton->ReleaseMouse();
-        }
-    }
-}
+            m_moveDownButton->SetFocus();
+        };
+    };
+};
 
 void ImagesPanel::OnMoveImageUp(wxCommandEvent & e)
 {
     UIntSet selImg = images_list->GetSelected();
-    if ( selImg.size() == 1) {
-        unsigned int i1 = *selImg.begin();
-        unsigned int i2 = i1 -1;
-        if (i1 > 0) {
-            images_list->SetItemState(i1,0,wxLIST_STATE_SELECTED);
+    size_t num = selImg.size();
+    if(num>0)
+    {
+        //first selected image
+        size_t i1 = *selImg.begin();
+        //image to move into. 
+        size_t i2 = i1-1;
+        //Test if there is room to move images up
+        if (i1 > 0 )
+        {
+            //Group repeated move commands within undo history
+            std::vector<PanoCommand*> cmds;
+            for (size_t i=0; i<num; i++)
+            {
+                cmds.push_back(new SwapImagesCmd(*pano,i2, i1));
+                i1++;
+                i2++;
+            }
             GlobalCmdHist::getInstance().addCommand(
-                new SwapImagesCmd(*pano,i1, i2)
-            );
+                    new PT::CombinedPanoCommand(*pano, cmds));
             // set new selection
-            images_list->SelectSingleImage(i2);
+            images_list->SelectImageRange(*selImg.begin()-1,*selImg.begin()+num-2);
             // Bring the focus back to the button.
-            m_moveUpButton->CaptureMouse();
-            m_moveUpButton->ReleaseMouse();
-        }
-    }
-}
+            m_moveUpButton->SetFocus();
+        };
+    };
+};
 
 void ImagesPanel::ReloadCPDetectorSettings()
 {
