@@ -67,7 +67,6 @@
 #include "base_wx/PTWXDlg.h"
 
 #include "base_wx/huginConfig.h"
-
 #include "hugin/AboutDialog.h"
 
 #if HUGIN_HSI
@@ -109,7 +108,7 @@ bool PanoDropTarget::OnDropFiles(wxCoord x, wxCoord y, const wxArrayString& file
             return true;
         }
     }
-    
+
     // try to add as images
     std::vector<std::string> filesv;
     bool foundForbiddenChars=false;
@@ -193,7 +192,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
 
     EVT_MENU(XRCID("ID_CP_TABLE"), MainFrame::OnShowCPFrame)
     EVT_BUTTON(XRCID("ID_CP_TABLE"),MainFrame::OnShowCPFrame)
-    
+
     EVT_MENU(XRCID("ID_SHOW_PANEL_ASSISTANT"), MainFrame::OnShowPanel)
     EVT_MENU(XRCID("ID_SHOW_PANEL_IMAGES"), MainFrame::OnShowPanel)
     EVT_MENU(XRCID("ID_SHOW_PANEL_LENS"), MainFrame::OnShowPanel)
@@ -251,7 +250,7 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
             // place text on bitmap.
             dc.DrawText(version, bitmap.GetWidth() - tw - 3, bitmap.GetHeight() - th - 3);
         }
-       
+
         splash = new wxSplashScreen(bitmap,
                                     wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_NO_TIMEOUT,
                                     0, NULL, -1, wxDefaultPosition,
@@ -290,7 +289,7 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
     wxDir dir(GetDataPath()+wxT("plugins"));
     wxString filename;
     bool cont=dir.GetFirst(&filename,wxT("*.py"),wxDIR_FILES|wxDIR_HIDDEN);
-    std::list<PluginItem> items;
+    PluginItems items;
     while(cont)
     {
         wxFileName file(dir.GetName(),filename);
@@ -305,10 +304,9 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
     items.sort(comparePluginItem);
 
     int pluginID=wxID_HIGHEST+2000;
-    for(list<PluginItem>::const_iterator it=items.begin();it!=items.end();it++)
+    for(PluginItems::const_iterator it=items.begin();it!=items.end();it++)
     {
         PluginItem item=*it;
-        // skip incompatible plugins
         int categoryID=pluginMenu->FindItem(item.GetCategory());
         wxMenu* categoryMenu;
         if(categoryID==wxNOT_FOUND)
@@ -326,8 +324,10 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
         pluginID++;
     };
     // show the new menu
-    menubar->Insert(menubar->GetMenuCount()-2,pluginMenu,_("&Actions"));
-
+    if(pluginMenu->GetMenuItemCount()>0)
+    {
+        menubar->Insert(menubar->GetMenuCount()-2,pluginMenu,_("&Actions"));
+    };
 #else
     GetMenuBar()->Enable(XRCID("action_python_script"), false);
 #endif
@@ -337,7 +337,7 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
 
     // Disable tools by default
     enableTools(false);
-	
+
     // put an "unknown" object in an xrc file and
     // take as wxObject (second argument) the return value of wxXmlResource::Get
     // finish the images_panel
@@ -351,7 +351,6 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
     images_panel = XRCCTRL(*this, "images_panel_unknown", ImagesPanel);
     assert(images_panel);
     images_panel->Init(&pano);
-
     DEBUG_TRACE("");
 
     m_notebook = XRCCTRL((*this), "controls_notebook", wxNotebook);
@@ -479,7 +478,7 @@ MainFrame::MainFrame(wxWindow* parent, Panorama & pano)
         delete splash;
     }
     wxYield();
-	
+
     // disable automatic Layout() calls, to it by hand
     SetAutoLayout(false);
 
@@ -557,13 +556,13 @@ void MainFrame::panoramaChanged(PT::Panorama &pano)
 
 void MainFrame::RestoreLayout()
 {
-    DEBUG_TRACE("");	
+    DEBUG_TRACE("");
     // restore layout of child widgets, now that all widgets have been created,
     // are of similar size
 //    cpe->RestoreLayout();
 //    lens_panel->RestoreLayout();
 //    images_panel->RestoreLayout();
-    DEBUG_TRACE("");	
+    DEBUG_TRACE("");
 }
 
 //void MainFrame::panoramaChanged(PT::Panorama &panorama)
@@ -587,7 +586,7 @@ bool MainFrame::CloseProject(bool cancelable)
 {
     if (pano.isDirty()) {
         wxMessageDialog message(this,
-                                _("Save changes to the panorama before closing?"), 
+                                _("Save changes to the panorama before closing?"),
 #ifdef _WINDOWS
                                 _("Hugin"),
 #else
@@ -696,7 +695,9 @@ void MainFrame::OnSaveProject(wxCommandEvent & e)
                                                               "",
                                                               outputFiles,
                                                               makefile,
-                                                              tmpDir);
+                                                              tmpDir,
+                                                              true,
+                                                              0);
         }
         SetStatusText(wxString::Format(_("saved project %s"), m_filename.c_str()),0);
         this->SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
@@ -864,13 +865,33 @@ void MainFrame::OnLoadProject(wxCommandEvent & e)
                          _("Project files (*.pto,*.ptp,*.pts,*.oto)|*.pto;*.ptp;*.pts;*.oto;|All files (*)|*"),
                          wxFD_OPEN, wxDefaultPosition);
         dlg.SetDirectory(defaultdir);
-        if (dlg.ShowModal() == wxID_OK) {
-            // remove old images from cache
-            ImageCache::getInstance().flush();
-
+        if (dlg.ShowModal() == wxID_OK)
+        {
             wxString filename = dlg.GetPath();
-            LoadProjectFile(filename);
-            return;
+            if(vigra::isImage(filename.mb_str(HUGIN_CONV_FILENAME)))
+            {
+                if(wxMessageBox(wxString::Format(_("File %s is an image file and not a project file.\nThis file can't be open with File, Open.\nDo you want instead add this image file to the current project?"),filename.c_str()),
+#ifdef __WXMSW__
+                    _("Hugin"),
+#else
+                    wxT(""),
+#endif
+                    wxYES_NO | wxICON_QUESTION)==wxYES)
+                {
+                    wxArrayString filenameArray;
+                    filenameArray.Add(filename);
+                    AddImages(filenameArray);
+                };
+                return;
+            }
+            else
+            {
+                // remove old images from cache
+                ImageCache::getInstance().flush();
+
+                LoadProjectFile(filename);
+                return;
+            };
         }
     }
     // do not close old project
@@ -935,38 +956,13 @@ void MainFrame::OnAddImages( wxCommandEvent& event )
     if (dlg.ShowModal() == wxID_OK) {
         // get the selections
         wxArrayString Pathnames;
-        wxArrayString Filenames;
         dlg.GetPaths(Pathnames);
-        dlg.GetFilenames(Filenames);
 
         // e safe the current path to config
         config->Write(wxT("/actualPath"), dlg.GetDirectory());  // remember for later
 
-        bool foundForbiddenChars=false;
-        for(unsigned int i=0;i<Pathnames.GetCount(); i++)
-           foundForbiddenChars=foundForbiddenChars || containsInvalidCharacters(Pathnames[i]);
-        if(foundForbiddenChars)
-        {
-            wxMessageBox(wxString::Format(_("The filename(s) contains one of the following invalid characters: %s\nHugin can not work with these filenames. Please rename your file(s) and try again."),getInvalidCharacters().c_str()),
-                _("Error"),wxOK | wxICON_EXCLAMATION,this);
-        }
-        else
-        {
-            std::vector<std::string> filesv;
-            for (unsigned int i=0; i< Pathnames.GetCount(); i++) {
-                filesv.push_back((const char *)Pathnames[i].mb_str(HUGIN_CONV_FILENAME));
-            }
+        AddImages(Pathnames);
 
-            // we got some images to add.
-            if (filesv.size() > 0) {
-                // use a Command to ensure proper undo and updating of GUI
-                // parts
-                wxBusyCursor();
-                GlobalCmdHist::getInstance().addCommand(
-                    new wxAddImagesCmd(pano,filesv)
-                    );
-            };
-        };
         DEBUG_INFO ( wxString::Format(wxT("img_ext: %d"), dlg.GetFilterIndex()).mb_str(wxConvLocal) )
         // save the image extension
         switch ( dlg.GetFilterIndex() ) {
@@ -987,6 +983,35 @@ void MainFrame::OnAddImages( wxCommandEvent& event )
     DEBUG_TRACE("");
 }
 
+void MainFrame::AddImages(wxArrayString& filenameArray)
+{
+    bool foundForbiddenChars=false;
+    for(unsigned int i=0;i<filenameArray.GetCount(); i++)
+        foundForbiddenChars=foundForbiddenChars || containsInvalidCharacters(filenameArray[i]);
+    if(foundForbiddenChars)
+    {
+        wxMessageBox(wxString::Format(_("The filename(s) contains one of the following invalid characters: %s\nHugin can not work with these filenames. Please rename your file(s) and try again."),getInvalidCharacters().c_str()),
+            _("Error"),wxOK | wxICON_EXCLAMATION,this);
+    }
+    else
+    {
+        std::vector<std::string> filesv;
+        for (unsigned int i=0; i< filenameArray.GetCount(); i++) {
+            filesv.push_back((const char *)filenameArray[i].mb_str(HUGIN_CONV_FILENAME));
+        }
+
+        // we got some images to add.
+        if (filesv.size() > 0) {
+            // use a Command to ensure proper undo and updating of GUI
+            // parts
+            wxBusyCursor();
+            GlobalCmdHist::getInstance().addCommand(
+                new wxAddImagesCmd(pano,filesv)
+                );
+        };
+    };
+};
+
 time_t ReadExifTime(const char* filename)
 {
     Exiv2::Image::AutoPtr image;
@@ -1175,7 +1200,6 @@ void MainFrame::OnAddTimeImages( wxCommandEvent& event )
         );
 }
 
-
 void MainFrame::OnShowDonate(wxCommandEvent & e)
 {
     wxLaunchDefaultBrowser(wxT("http://sourceforge.net/project/project_donations.php?group_id=77506"));
@@ -1225,14 +1249,14 @@ void MainFrame::OnAbout(wxCommandEvent & e)
     wxDialog dlg;
 	wxString strFile;
 	wxString langCode;
-	
+
     wxXmlResource::Get()->LoadDialog(&dlg, this, wxT("about_dlg"));
 
 #if __WXMAC__ && defined MAC_SELF_CONTAINED_BUNDLE
     //rely on the system's locale choice
     strFile = MacGetPathToBundledResourceFile(CFSTR("about.htm"));
     if(strFile!=wxT("")) XRCCTRL(dlg,"about_html",wxHtmlWindow)->LoadPage(strFile);
-#else    
+#else
     //if the language is not default, load custom About file (if exists)
     langCode = huginApp::Get()->GetLocale().GetName().Left(2).Lower();
     DEBUG_INFO("Lang Code: " << langCode.mb_str(wxConvLocal));
@@ -1335,7 +1359,7 @@ void MainFrame::OnTipOfDay(wxCommandEvent& WXUNUSED(e))
     //TODO: tips not localisable
     DEBUG_INFO("Tip index: " << nValue);
     strFile = GetXRCPath() + wxT("data/tips.txt");  //load default file
-	
+
     DEBUG_INFO("Reading tips from " << strFile.mb_str(wxConvLocal));
     wxTipProvider *tipProvider = new LocalizedFileTipProvider(strFile, nValue);
     bShowAtStartup = wxShowTip(this, tipProvider,(nValue ? true:false));
@@ -1389,7 +1413,7 @@ void MainFrame::OnTogglePreviewFrame(wxCommandEvent & e)
     }
     preview_frame->Show();
     preview_frame->Raise();
-	
+
 	// we need to force an update since autoupdate fires
 	// before the preview frame is shown
     wxCommandEvent dummy;
@@ -1406,7 +1430,7 @@ void MainFrame::OnToggleGLPreviewFrame(wxCommandEvent & e)
     }
     gl_preview_frame->Show();
 #if defined __WXMSW__
-    // on wxMSW Show() does not send OnShowEvent needed to update the 
+    // on wxMSW Show() does not send OnShowEvent needed to update the
     // visibility state of the fast preview windows
     // so explicit calling this event handler
     wxShowEvent se;
@@ -1464,7 +1488,7 @@ void MainFrame::OnMergeProject(wxCommandEvent & e)
                      _("Project files (*.pto,*.ptp,*.pts,*.oto)|*.pto;*.ptp;*.pts;*.oto;|All files (*)|*"),
                      wxFD_OPEN, wxDefaultPosition);
     dlg.SetDirectory(defaultdir);
-    if (dlg.ShowModal() == wxID_OK) 
+    if (dlg.ShowModal() == wxID_OK)
     {
         wxString filename = dlg.GetPath();
         wxFileName fname(filename);
@@ -1475,7 +1499,7 @@ void MainFrame::OnMergeProject(wxCommandEvent & e)
             PanoramaMemento newPano;
             std::ifstream in((const char *)fname.GetFullPath().mb_str(HUGIN_CONV_FILENAME));
             int ptoversion=0;
-            if (newPano.loadPTScript(in, ptoversion, (const char *)path.mb_str(HUGIN_CONV_FILENAME))) 
+            if (newPano.loadPTScript(in, ptoversion, (const char *)path.mb_str(HUGIN_CONV_FILENAME)))
             {
                 Panorama new_pano;
                 new_pano.setMemento(newPano);
@@ -1486,7 +1510,7 @@ void MainFrame::OnMergeProject(wxCommandEvent & e)
                 pano.clearDirty();
                 m_mruFiles.AddFileToHistory(fname.GetFullPath());
                 // force update of preview window
-                if ( !(preview_frame->IsIconized() ||(! preview_frame->IsShown()) ) ) 
+                if ( !(preview_frame->IsIconized() ||(! preview_frame->IsShown()) ) )
                 {
                     wxCommandEvent dummy;
                     preview_frame->OnUpdate(dummy);
@@ -1529,7 +1553,7 @@ void MainFrame::OnOpenPTBatcher(wxCommandEvent & e)
 	wxString huginPath = getExePath(wxGetApp().argv[0])+wxFileName::GetPathSeparator();
 #else
 	wxString huginPath = _T("");	//we call the batch processor directly without path on linux
-#endif	
+#endif
 	wxExecute(huginPath+_T("PTBatcherGUI"));
 }
 
@@ -1678,7 +1702,7 @@ void MainFrame::OnRemoveCPinMasks(wxCommandEvent & e)
         GlobalCmdHist::getInstance().addCommand(
                     new PT::RemoveCtrlPointsCmd(pano,cps)
                     );
-        wxMessageBox(wxString::Format(_("Removed %d control points"), cps.size()), 
+        wxMessageBox(wxString::Format(_("Removed %d control points"), cps.size()),
                    _("Removing control points in masks"),wxOK|wxICON_INFORMATION,this);
     };
 }
@@ -1688,13 +1712,14 @@ void MainFrame::OnPythonScript(wxCommandEvent & e)
 {
     wxString fname;
     wxFileDialog dlg(this,
-		     _("Select python script"),
-		     wxConfigBase::Get()->Read(wxT("/lensPath"),wxT("")), wxT(""),
-		     _("Python script (*.py)|*.py|All files (*.*)|*.*"),
-		     wxFD_OPEN, wxDefaultPosition);
+            _("Select python script"),
+            wxConfigBase::Get()->Read(wxT("/lensPath"),wxT("")), wxT(""),
+            _("Python script (*.py)|*.py|All files (*.*)|*.*"),
+            wxFD_OPEN, wxDefaultPosition);
     dlg.SetDirectory(wxConfigBase::Get()->Read(wxT("/pythonScriptPath"),wxT("")));
 
-    if (dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK)
+    {
         wxString filename = dlg.GetPath();
         wxConfig::Get()->Write(wxT("/pythonScriptPath"), dlg.GetDirectory());
         std::string scriptfile((const char *)filename.mb_str(HUGIN_CONV_FILENAME));
@@ -1839,7 +1864,7 @@ void MainFrame::OnSize(wxSizeEvent &e)
 
 CPDetectorSetting& MainFrame::GetDefaultSetting()
 {
-    return images_panel->GetDefaultSetting(); 
+    return images_panel->GetDefaultSetting();
 };
 
 void MainFrame::RestoreLayoutOnNextResize()
@@ -1982,7 +2007,7 @@ struct celeste::svm_model* MainFrame::GetSVMModel()
         wxString wxstrModelFileName = huginApp::Get()->GetDataPath() + wxT(HUGIN_CELESTE_MODEL);
         // convert wxString to string
         string strModelFileName(wxstrModelFileName.mb_str(HUGIN_CONV_FILENAME));
-				
+
         // SVM model file
         if (! wxFile::Exists(wxstrModelFileName) ) {
             wxMessageBox(wxString::Format(_("Celeste model expected in %s not found, Hugin needs to be properly installed."),wxstrModelFileName.c_str()), _("Fatal Error"));
