@@ -131,6 +131,9 @@ PreferencesDialog::PreferencesDialog(wxWindow *parent)
     *lp = wxLANGUAGE_CZECH;
     lang_choice->Append(_("Czech"), lp);
     lp = new long;
+    *lp = wxLANGUAGE_DANISH;
+    lang_choice->Append(_("Danish"), lp);
+    lp = new long;
     *lp = wxLANGUAGE_DUTCH;
     lang_choice->Append(_("Dutch"), lp);
     lp = new long;
@@ -486,6 +489,8 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         MY_STR_VAL("prefs_ass_editor_args", cfg->Read(wxT("/Stitcher/EditorArgs"),
                    wxT(HUGIN_STITCHER_EDITOR_ARGS)));
         MY_CHOICE_VAL("prefs_ass_preview", cfg->Read(wxT("/Assistant/PreviewWindow"), HUGIN_ASS_PREVIEW));
+        t = cfg->Read(wxT("/Assistant/Linefind"), HUGIN_ASS_LINEFIND) == 1;
+        MY_BOOL_VAL("prefs_ass_linefind", t);
         t = cfg->Read(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO) == 1;
         MY_BOOL_VAL("prefs_celeste_auto", t);
         t = cfg->Read(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN) == 1;
@@ -562,6 +567,13 @@ void PreferencesDialog::UpdateDisplayData(int panel)
         t = cfg->Read(wxT("/Processor/verbose"), HUGIN_PROCESSOR_VERBOSE) == 1;
         MY_BOOL_VAL("pref_processor_verbose", t);
         UpdateProcessorControls();
+
+        t = cfg->Read(wxT("/output/useExiftool"), 1l) == 1;
+        MY_BOOL_VAL("pref_exiftool_metadata", t);
+
+        int nThreads = cfg->Read(wxT("/output/NumberOfThreads"), 0l);
+        MY_SPIN_VAL("prefs_output_NumberOfThreads", nThreads);
+
     }
 
     if (panel==0 || panel == 6){
@@ -680,6 +692,7 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
             cfg->Write(wxT("/Stitcher/Editor"), wxT(HUGIN_STITCHER_EDITOR));
             cfg->Write(wxT("/Stitcher/EditorArgs"), wxT(HUGIN_STITCHER_EDITOR_ARGS));
             cfg->Write(wxT("/Assistant/PreviewWindow"), HUGIN_ASS_PREVIEW);
+            cfg->Write(wxT("/Assistant/Linefind"), HUGIN_ASS_LINEFIND);
             cfg->Write(wxT("/Celeste/Auto"), HUGIN_CELESTE_AUTO);
             cfg->Write(wxT("/Assistant/AutoCPClean"), HUGIN_ASS_AUTO_CPCLEAN);
         }
@@ -720,6 +733,8 @@ void PreferencesDialog::OnRestoreDefaults(wxCommandEvent & e)
             cfg->Write(wxT("/Processor/parallel"), HUGIN_PROCESSOR_PARALLEL);
             cfg->Write(wxT("/Processor/overwrite"), HUGIN_PROCESSOR_OVERWRITE);
             cfg->Write(wxT("/Processor/verbose"), HUGIN_PROCESSOR_VERBOSE);
+            cfg->Write(wxT("/output/useExiftool"), 1l);
+            cfg->Write(wxT("/output/NumberOfThreads"), 0l);
 
         }
         if (noteb->GetSelection() == 5) {
@@ -767,6 +782,7 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Assistant/nControlPoints"), MY_G_SPIN_VAL("prefs_ass_nControlPoints"));
     cfg->Write(wxT("/Assistant/panoDownsizeFactor"), MY_G_SPIN_VAL("prefs_ass_panoDownsizeFactor") / 100.0);
     cfg->Write(wxT("/Assistant/PreviewWindow"), MY_G_CHOICE_VAL("prefs_ass_preview"));
+    cfg->Write(wxT("/Assistant/Linefind"), MY_G_BOOL_VAL("prefs_ass_linefind"));
     cfg->Write(wxT("/Celeste/Auto"), MY_G_BOOL_VAL("prefs_celeste_auto"));
     cfg->Write(wxT("/Assistant/AutoCPClean"), MY_G_BOOL_VAL("prefs_auto_cpclean"));
     // editor
@@ -849,6 +865,8 @@ void PreferencesDialog::UpdateConfigData()
     cfg->Write(wxT("/Processor/overwrite"), MY_G_BOOL_VAL("pref_processor_overwrite"));
     cfg->Write(wxT("/Processor/verbose"), MY_G_BOOL_VAL("pref_processor_verbose"));
 
+    cfg->Write(wxT("/output/useExiftool"), MY_G_BOOL_VAL("pref_exiftool_metadata"));
+    cfg->Write(wxT("/output/NumberOfThreads"), MY_G_SPIN_VAL("prefs_output_NumberOfThreads"));
     /////
     /// STITCHING
     cfg->Write(wxT("/Nona/Interpolator"), MY_G_CHOICE_VAL("prefs_nona_interpolator"));
