@@ -375,8 +375,8 @@ PreviewFrame::PreviewFrame(wxFrame * frame, PT::Panorama &pano)
     SetStatusText(_("Center panorama with left mouse button, set horizon with right button"),0);
     wxAcceleratorEntry entries[3];
     entries[0].Set(wxACCEL_NORMAL,WXK_F11,ID_FULL_SCREEN);
-    entries[1].Set(wxACCEL_CTRL,(int)'Z',ID_UNDO);
-    entries[2].Set(wxACCEL_CTRL,(int)'R',ID_REDO);
+    entries[1].Set(wxACCEL_CMD,(int)'Z',ID_UNDO);
+    entries[2].Set(wxACCEL_CMD,(int)'R',ID_REDO);
     wxAcceleratorTable accel(3, entries);
     SetAcceleratorTable(accel);
 #ifdef __WXGTK__
@@ -507,7 +507,7 @@ void PreviewFrame::panoramaChanged(Panorama &pano)
     m_VFOVSlider->SetValue(roundi(opts.getVFOV()));
 
     m_oldProjFormat = opts.getProjection();
-
+    updatePano();
 }
 
 void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
@@ -579,6 +579,7 @@ void PreviewFrame::panoramaImagesChanged(Panorama &pano, const UIntSet &changed)
 		DEBUG_INFO("New m_ButtonPanel width: " << (m_ButtonPanel->GetSize()).GetWidth());
 		DEBUG_INFO("New m_ButtonPanel Height: " << (m_ButtonPanel->GetSize()).GetHeight());
     }
+    updatePano();
 }
 
 
@@ -633,8 +634,6 @@ void PreviewFrame::OnCenterHorizontally(wxCommandEvent & e)
     GlobalCmdHist::getInstance().addCommand(
         new PT::CenterPanoCmd(m_pano)
         );
-    // fit pano afterwards
-    OnFitPano(e);
 }
 
 void PreviewFrame::OnStraighten(wxCommandEvent & e)
@@ -644,13 +643,6 @@ void PreviewFrame::OnStraighten(wxCommandEvent & e)
     GlobalCmdHist::getInstance().addCommand(
         new PT::StraightenPanoCmd(m_pano)
         );
-    if (m_pano.getOptions().getHFOV() > 359) {
-        // adjust canvas size for 360 deg panos
-        OnFitPano(e);
-    } else {
-        // also center non 360 deg panos
-        OnCenterHorizontally(e);
-    }
 }
 
 void PreviewFrame::OnUpdate(wxCommandEvent& event)
@@ -971,13 +963,27 @@ void PreviewFrame::OnFullScreen(wxCommandEvent & e)
 
 void PreviewFrame::OnUndo(wxCommandEvent &e)
 {
-    wxCommandEvent dummy(wxEVT_COMMAND_MENU_SELECTED, XRCID("ID_EDITUNDO"));
-    m_parent->GetEventHandler()->AddPendingEvent(dummy);
+    if(GlobalCmdHist::getInstance().canUndo())
+    {
+        wxCommandEvent dummy(wxEVT_COMMAND_MENU_SELECTED, XRCID("ID_EDITUNDO"));
+        m_parent->GetEventHandler()->AddPendingEvent(dummy);
+    }
+    else
+    {
+        wxBell();
+    };
 };
 
 void PreviewFrame::OnRedo(wxCommandEvent &e)
 {
-    wxCommandEvent dummy(wxEVT_COMMAND_MENU_SELECTED, XRCID("ID_EDITREDO"));
-    m_parent->GetEventHandler()->AddPendingEvent(dummy);
+    if(GlobalCmdHist::getInstance().canRedo())
+    {
+        wxCommandEvent dummy(wxEVT_COMMAND_MENU_SELECTED, XRCID("ID_EDITREDO"));
+        m_parent->GetEventHandler()->AddPendingEvent(dummy);
+    }
+    else
+    {
+        wxBell();
+    };
 };
 
