@@ -371,10 +371,6 @@ CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, Panorama & pano, co
     tmp.Printf(wxT("%d"), (int) firstImg.getProjection());
     autopanoArgs.Replace(wxT("%f"), tmp);
 
-    // build a list of all image files, and a corrosponding connection map.
-    // local img nr -> global (panorama) img number
-    std::map<int,int> imgMapping;
-
     long idx = autopanoArgs.Find(wxT("%namefile")) ;
     DEBUG_DEBUG("find %namefile in '"<< autopanoArgs.mb_str(wxConvLocal) << "' returned: " << idx);
     bool use_namefile = idx >=0;
@@ -398,13 +394,10 @@ CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, Panorama & pano, co
         DEBUG_DEBUG("before replace %namefile: " << autopanoArgs.mb_str(wxConvLocal));
         autopanoArgs.Replace(wxT("%namefile"), namefile_name);
         DEBUG_DEBUG("after replace %namefile: " << autopanoArgs.mb_str(wxConvLocal));
-        int imgNr=0;
         for(UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); it++)
         {
-            imgMapping[imgNr] = *it;
             namefile.Write(wxString(pano.getImage(*it).getFilename().c_str(), HUGIN_CONV_FILENAME));
             namefile.Write(wxT("\r\n"));
-            imgNr++;
         }
         // close namefile
         if (namefile_name != wxString(wxT(""))) {
@@ -412,12 +405,9 @@ CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, Panorama & pano, co
         }
     } else {
         string imgFiles;
-        int imgNr=0;
         for(UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); it++)
         {
-            imgMapping[imgNr] = *it;
             imgFiles.append(" ").append(quoteFilename(pano.getImage(*it).getFilename()));
-            imgNr++;
         }
         autopanoArgs.Replace(wxT("%i"), wxString (imgFiles.c_str(), HUGIN_CONV_FILENAME));
     }
@@ -429,7 +419,12 @@ CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, Panorama & pano, co
         autopanoArgs.Replace(wxT("%s"), ptoinfile_name);
 
         ofstream ptoinstream(ptoinfile_name.mb_str(wxConvFile));
-        pano.printPanoramaScript(ptoinstream, pano.getOptimizeVector(), pano.getOptions(), imgs, false);
+        //delete all existing control points in temp project
+        //otherwise the existing control points will be loaded again
+        Panorama tempPano=pano.duplicate();
+        CPVector emptyCPV;
+        tempPano.setCtrlPoints(emptyCPV);
+        tempPano.printPanoramaScript(ptoinstream, tempPano.getOptimizeVector(), tempPano.getOptions(), imgs, false);
     }
 
 #ifdef __WXMSW__
@@ -581,17 +576,10 @@ CPVector AutoPanoSift::automatch(CPDetectorSetting &setting, PT::Panorama & pano
     tmp.Printf(wxT("%d"), (int) firstImg.getProjection());
     matcherArgs.Replace(wxT("%f"), tmp);
 
-    // build a list of all image files, and a corrosponding connection map.
-    // local img nr -> global (panorama) img number
-    std::map<int,int> imgMapping;
-
     wxString imgFiles;
-    int imgNr=0;
     for(UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); it++)
     {
-        imgMapping[imgNr] = *it;
         imgFiles.append(wxT(" ")).append(wxQuoteFilename(keyFiles[*it]));
-        imgNr++;
      };
      matcherArgs.Replace(wxT("%k"), wxString (imgFiles.wc_str(), HUGIN_CONV_FILENAME));
 
@@ -658,16 +646,10 @@ CPVector AutoPanoKolor::automatch(CPDetectorSetting &setting, Panorama & pano, c
     // write default autopano.kolor.com flags
     wxString autopanoArgs = setting.GetArgs();
 
-    // build a list of all image files, and a corrosponding connection map.
-    // local img nr -> global (panorama) img number
-    std::map<int,int> imgMapping;
     string imgFiles;
-    int imgNr=0;
     for(UIntSet::const_iterator it = imgs.begin(); it != imgs.end(); it++)
     {
-        imgMapping[imgNr] = *it;
         imgFiles.append(" ").append(quoteFilename(pano.getImage(*it).getFilename()));
-        imgNr++;
     }
 
     wxString ptofilepath = wxFileName::CreateTempFileName(wxT("ap_res"));
@@ -971,7 +953,21 @@ CPVector AutoPanoSiftMultiRow::automatch(CPDetectorSetting &setting, Panorama &
             optvars.push_back(imgopt);
         }
         optPano.setOptimizeVector(optvars);
+
+        // remove vertical and horizontal control points
+        CPVector backupOldCPS = optPano.getCtrlPoints();
+        CPVector backupNewCPS;
+        for (CPVector::const_iterator it = backupOldCPS.begin(); it != backupOldCPS.end(); it++) {
+            if (it->mode == ControlPoint::X_Y)
+            {
+                backupNewCPS.push_back(*it);
+            }
+        }
+        optPano.setCtrlPoints(backupNewCPS);
+        // do a first pairwise optimisation step
+        HuginBase::AutoOptimise::autoOptimise(optPano,false);
         HuginBase::PTools::optimize(optPano);
+        optPano.setCtrlPoints(backupOldCPS);
         //and find cp on overlapping images
         //work only on image pairs, which are not yet connected
         AutoPanoSiftPreAlign matcher;
