@@ -180,11 +180,12 @@ bool PanoramaMakefilelibExport::createItems()
         mf::Variable* vtmpdir = mgr.own(new mf::Variable("TMPDIR", tmpDir));
         vtmpdir->setExport(true); vtmpdir->getDef().add();
 #else
+        //special quoting for environment variable on windows
+        //variable TMP should not be exported with set
+        //variable TMP should not be quoted with quotes, appling special quoting
         mgr.own_add(new Comment("set temporary directory for not UNIX_LIKE"));
-        mf::Variable* vtmpdir = mgr.own(new mf::Variable("TEMP", tmpDir));
-        vtmpdir->setExport(true); vtmpdir->getDef().add();
-        mf::Variable* vtmpdir2 = mgr.own(new mf::Variable("TMP", tmpDir));
-        vtmpdir2->setExport(true); vtmpdir2->getDef().add();
+        mf::Variable* vtmpdir = mgr.own(new mf::Variable("TMP", Makefile::quoteEnvironment(tmpDir),Makefile::NONE));
+        vtmpdir->getDef().add();
 #endif
     }
 
@@ -216,6 +217,13 @@ bool PanoramaMakefilelibExport::createItems()
     mf::Variable* vexiftool = mgr.own(new mf::Variable("EXIFTOOL", progs.exiftool));
     vexiftool->getDef().add();
 
+    if(nrThreads>0)
+    {
+        //set environment variable for OpenMP enabled enblend/enfuse
+        mf::Variable* vOpenMPThreads = mgr.own(new mf::Variable("OMP_NUM_THREADS", nrThreads));
+        vOpenMPThreads->setExport(true);
+        vOpenMPThreads->getDef().add();
+    };
     //----------
     // Project parameters
     mgr.own_add(new Comment("Project parameters"));
@@ -248,8 +256,16 @@ bool PanoramaMakefilelibExport::createItems()
         vnonaldr = mgr.own(new mf::Variable("NONA_LDR_REMAPPED_COMP", val, Makefile::NONE));
         vnonaldr->getDef().add();
 
-        vnonaopts = mgr.own(new mf::Variable("NONA_OPTS",
-                opts.remapUsingGPU ? "-g " : "", Makefile::NONE));
+        valuestream.str("");
+        if(opts.remapUsingGPU)
+        {
+            valuestream << "-g ";
+        };
+        if(nrThreads>0)
+        {
+            valuestream << "-t " << nrThreads;
+        };
+        vnonaopts = mgr.own(new mf::Variable("NONA_OPTS",valuestream.str(), Makefile::NONE));
         vnonaopts->getDef().add();
     }
 
@@ -674,7 +690,10 @@ bool PanoramaMakefilelibExport::createItems()
     // test hugin_hdrmerge
     createcheckProgCmd(*test,"hugin_hdrmerge",vhdrmerge->getRef()+" -h");
     // test exiftool
-    createcheckProgCmd(*test,"exiftool",vexiftool->getRef()+" -ver");
+    if(copyMetadata)
+    {
+        createcheckProgCmd(*test,"exiftool",vexiftool->getRef()+" -ver");
+    };
     test->add();
 
     //----------
@@ -862,8 +881,11 @@ bool PanoramaMakefilelibExport::createItems()
         ruleldr->addPrereq(ldr_stacks_input[i]);
         ruleldr->addCommand(venfuse->getRef() +" "+ venfuseopts->getRef() + " -o " +
                 ldr_stacks_shell[i]->getRef() +" -- "+ ldr_stacks_input_shell[i]->getRef());
-        ruleldr->addCommand("-" + vexiftool->getRef() + " -overwrite_original_in_place -TagsFromFile " +
-                vinimage1shell->getRef() +" "+ vexiftoolcopyargs->getRef() +" "+ ldr_stacks_shell[i]->getRef());
+        if(copyMetadata)
+        {
+            ruleldr->addCommand("-" + vexiftool->getRef() + " -overwrite_original_in_place -TagsFromFile " +
+                    vinimage1shell->getRef() +" "+ vexiftoolcopyargs->getRef() +" "+ ldr_stacks_shell[i]->getRef());
+        };
 
         Rule* rulehdr = mgr.own(new Rule()); rulehdr->add();
         rulehdr->addTarget(hdr_stacks[i]);
@@ -890,7 +912,10 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addTarget(vldrblended);
         rule->addPrereq(vldrlayers);
         rule->addCommand(enblendcmd + vldrblendedshell->getRef() +" -- "+ vldrlayersshell->getRef());
-        rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
+        if(copyMetadata)
+        {
+            rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
+        };
 
         // for LDR exposure blend planes
         for(unsigned i=0; i < exposures.size(); i++)
@@ -901,7 +926,10 @@ bool PanoramaMakefilelibExport::createItems()
             rule->addCommand(venblend->getRef() +" "+ venblendexposurecomp->getRef() + " " +
                 venblendopts->getRef() + " -o " + ldrexp_stacks_shell[i]->getRef() + " -- " + 
                 ldrexp_stacks_input_shell[i]->getRef());
-            rule->addCommand(exifcmd + ldrexp_stacks_shell[i]->getRef());
+            if(copyMetadata)
+            {
+                rule->addCommand(exifcmd + ldrexp_stacks_shell[i]->getRef());
+            };
         }
 
         // rules for enfuse blending
@@ -909,7 +937,10 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addTarget(vldrstackedblended);
         rule->addPrereq(vldrstacks);
         rule->addCommand(enblendcmd + vldrstackedblendedshell->getRef() +" -- "+ vldrstacksshell->getRef());
-        rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
+        if(copyMetadata)
+        {
+            rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
+        };
 
         // rules for fusing blended layers
         rule = mgr.own(new Rule()); rule->add();
@@ -917,7 +948,10 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addPrereq(vldrexposurelayers);
         rule->addCommand(venfuse->getRef() +" "+ venblendldrcomp->getRef() +" "+ venfuseopts->getRef() + " -o " +
                 vldrexposurelayersfusedshell->getRef() +" -- "+ vldrexposurelayersshell->getRef());
-        rule->addCommand(exifcmd2 + vldrexposurelayersfusedshell->getRef());
+        if(copyMetadata)
+        {
+            rule->addCommand(exifcmd2 + vldrexposurelayersfusedshell->getRef());
+        };
 
         // rules for hdr blending
         rule = mgr.own(new Rule()); rule->add();
@@ -961,7 +995,10 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addPrereq(vldrlayers);
         rule->addCommand("-" + vrm->getRef() +" "+ vldrblendedshell->getRef());
         rule->addCommand(ptrollercmd + vldrblendedshell->getRef() +" "+ vldrlayersshell->getRef());
-        rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
+        if(copyMetadata)
+        {
+            rule->addCommand(exifcmd2 + vldrblendedshell->getRef());
+        };
 
         // for LDR exposure blend planes
         for(unsigned i=0; i < exposures.size(); i++)
@@ -971,7 +1008,10 @@ bool PanoramaMakefilelibExport::createItems()
             rule->addPrereq(ldrexp_stacks_input[i]);
             rule->addCommand("-" + vrm->getRef() +" "+ ldrexp_stacks_shell[i]->getRef());
             rule->addCommand(ptrollercmd + ldrexp_stacks_shell[i]->getRef());
-            rule->addCommand(exifcmd + ldrexp_stacks_shell[i]->getRef());
+            if(copyMetadata)
+            {
+                rule->addCommand(exifcmd + ldrexp_stacks_shell[i]->getRef());
+            };
         }
 
         rule = mgr.own(new Rule()); rule->add();
@@ -979,7 +1019,10 @@ bool PanoramaMakefilelibExport::createItems()
         rule->addPrereq(vldrstacks);
         rule->addCommand("-" + vrm->getRef() +" "+ vldrstackedblendedshell->getRef());
         rule->addCommand(ptrollercmd + vldrstackedblendedshell->getRef() +" "+ vldrstacksshell->getRef());
-        rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
+        if(copyMetadata)
+        {
+            rule->addCommand(exifcmd2 + vldrstackedblendedshell->getRef());
+        };
 
         // rules for non-blended HDR panoramas
         rule = mgr.own(new Rule()); rule->add();
