@@ -27,6 +27,7 @@
 
 #include "PTScriptParsing.h"
 #include "ImageVariableTranslate.h"
+#include "StandardImageVariableGroups.h"
 #include <panotools/PanoToolsInterface.h>
 #include <algorithms/basic/CalculateOverlap.h>
 
@@ -448,16 +449,6 @@ void Panorama::setImageFilename(unsigned int i, const std::string & fname)
     m_forceImagesUpdate = true;
 }
 
-void Panorama::setImageOptions(unsigned int i, const ImageOptions & opts)
-{
-    DEBUG_ASSERT(i < state.images.size());
-    // TODO: recenter crop, if required.
-    state.images[i]->setOptions(opts);
-    imageChanged(i);
-    m_forceImagesUpdate = true;
-}
-
-
 unsigned int Panorama::addCtrlPoint(const ControlPoint & point )
 {
     unsigned int nr = state.ctrlPoints.size();
@@ -734,8 +725,11 @@ void Panorama::printPanoramaScript(std::ostream & o,
                 img.printMaskLines(masklines,ic);
         }
 
+#if 0
+//panotools paramters, currently not used
         o << " u" << output.featherWidth
-          << (img.getOptions().morph ? " o" : "");
+          << (img.getMorph() ? " o" : "");
+#endif
         std::string fname = img.getFilename();
         if (stripPrefix.size() > 0) {
             // strip prefix from image names.
@@ -874,12 +868,15 @@ void Panorama::printStitcherScript(std::ostream & o,
             }
             vit->second.print(o) << " ";
         }
-        o << " u" << target.featherWidth << " m" << img.getOptions().ignoreFrameWidth
-          << (img.getOptions().morph ? " o" : "")
-          << " n\"" << img.getFilename() << "\"";
-        if (img.getOptions().docrop) {
+#if 0
+// panotools parameters, currently not used 
+        o << " u" << img.getFeatureWidth() 
+          << (img.getMorph() ? " o" : "");
+#endif
+        o << " n\"" << img.getFilename() << "\"";
+        if (img.getCropMode()!=SrcPanoImage::NO_CROP) {
             // print crop parameters
-            vigra::Rect2D c = img.getOptions().cropRect;
+            vigra::Rect2D c = img.getCropRect();
             o << " S" << c.left() << "," << c.right() << "," << c.top() << "," << c.bottom();
         }
         o << std::endl;
@@ -1197,6 +1194,8 @@ void Panorama::updateMasks(bool convertPosMaskToNeg)
     CalculateImageOverlap overlap(this);
     overlap.limitToImages(imgWithPosMasks);
     overlap.calculate(10);
+    ConstStandardImageVariableGroups variable_groups(*this);
+    ConstImageVariableGroup & lenses = variable_groups.getLenses();
     for(unsigned int i=0;i<state.images.size();i++)
     {
         if(state.images[i]->hasMasks())
@@ -1238,6 +1237,22 @@ void Panorama::updateMasks(bool convertPosMaskToNeg)
                                 transferMask(masks[j],i,imgStack);
                             };
                             break;
+                        case MaskPolygon::Mask_negative_lens:
+                            {
+                                unsigned int lensNr=lenses.getPartNumber(i);
+                                //copy masks to all image of the same lens
+                                UIntSet imgLens;
+                                for(unsigned int k=0;k<getNrOfImages();k++)
+                                {
+                                    if(lenses.getPartNumber(k)==lensNr)
+                                    {
+                                        masks[j].setImgNr(k);
+                                        masks[j].setMaskType(MaskPolygon::Mask_negative_lens);
+                                        state.images[k]->addActiveMask(masks[j]);
+                                    };
+                                };
+                            };
+                            break;
                     };
                 }
                 else
@@ -1302,6 +1317,22 @@ void Panorama::updateMasks(bool convertPosMaskToNeg)
                                 transferMask(masks[j],i,imgs);
                             };
                             break;
+                        case MaskPolygon::Mask_negative_lens:
+                            {
+                                unsigned int lensNr=lenses.getPartNumber(i);
+                                //copy masks to all image of the same lens
+                                UIntSet imgLens;
+                                for(unsigned int k=0;k<getNrOfImages();k++)
+                                {
+                                    if(lenses.getPartNumber(k)==lensNr)
+                                    {
+                                        masks[j].setImgNr(k);
+                                        masks[j].setMaskType(MaskPolygon::Mask_negative_lens);
+                                        state.images[k]->addActiveMask(masks[j]);
+                                    };
+                                };
+                            };
+                            break;
                     };
                 };
             };
@@ -1318,8 +1349,7 @@ void Panorama::updateCropMode(unsigned int imgNr)
     }
     else
     {
-        if (state.images[imgNr]->getProjection() == SrcPanoImage::CIRCULAR_FISHEYE || 
-            state.images[imgNr]->getProjection() == SrcPanoImage::FISHEYE_THOBY)
+        if (state.images[imgNr]->isCircularCrop())
         {
             state.images[imgNr]->setCropMode(SrcPanoImage::CROP_CIRCLE);
         }
@@ -1960,6 +1990,9 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
             skipNextLine = false;
             continue;
         }
+        //skip emtpy lines
+        if(line.empty())
+            continue;
         // check for a known line
         switch(line[0]) {
         case 'p':
@@ -2626,7 +2659,9 @@ bool PanoramaMemento::loadPTScript(std::istream &i, int & ptoVersion, const std:
 #undef image_variable
         new_img.setProjection((SrcPanoImage::Projection) iImgInfo[i].f);
 
+#if 0
         new_img.setFeatherWidth((unsigned int) iImgInfo[i].blend_radius);
+#endif
         
         // is this right?
         new_img.setExifCropFactor(iImgInfo[i].cropFactor);
