@@ -871,7 +871,7 @@ void PanoDetector::writeOutput()
 		return;
 	}
 
-    aOut << "# pto project file generated by Hugins cpfind" << endl << endl;
+    aOut << "# pto project file generated by Hugin's cpfind" << endl << endl;
 
     _panoramaInfo->removeDuplicateCtrlPoints();
 	AppBase::DocumentData::ReadWriteError err = _panoramaInfo->writeData(aOut);
